@@ -139,6 +139,27 @@
 #' For further details and instructions, see
 #' [future.apply::future_lapply()].
 #'
+#' @section Reporting on progress:
+#' How to report on progress is a frequently asked question, especially
+#' in long-running tasks and parallel processing.  The **foreach**
+#' framework does _not_ have a built-in mechanism for progress
+#' reporting(*).
+#'
+#' When using **doFuture**, and the Futureverse in general, for
+#' processing, the **progressr** package can be used to signal progress
+#' updates in a near-live fashion.  There is special argument related to
+#' `foreach()` or **doFuture** to achieve this. Instead, one calls a
+#' a, so called, "progressor" function within each iteration.  See
+#' the [**progressr**](https://cran.r-project.org/package=progressr)
+#' package and its `vignette(package = "progressr")` for examples.
+#'
+#' (*) The legacy **doSNOW** package uses a special `foreach()` argument
+#' `.options.doSNOW$progress` that can be used to make a progress update
+#' each time results from a parallel workers is returned. This approach
+#' is limited by how chunking works, requires the developer to set that
+#' argument, and the code becomes incompatible with foreach adaptors
+#' registered by other **doNnn** packages.
+#'
 #'
 #' @example incl/dofuture_OP.R
 #'
@@ -203,7 +224,7 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
   ## Support %globals%, %packages%, %seed%, ...
   opts <- getOption("future.disposable", NULL)
   for (name in names(opts)) {
-    options[[name]] <- opts[[name]]
+    options[name] <- opts[name]
   }
   options(future.disposable = NULL)
   
@@ -254,9 +275,10 @@ doFuture2 <- function(obj, expr, envir, data) {   #nolint
   if (is.null(stdout)) {
     stdout <- eval(formals(future)$stdout)
   }
-  
-  conditions <- options[["conditions"]]
-  if (is.null(conditions)) {
+
+  if ("conditions" %in% names(options)) {
+    conditions <- options[["conditions"]]
+  } else {
     conditions <- eval(formals(future)$conditions)
   }
 
